"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Jats = void 0;
const xml_js_1 = require("xml-js");
const utils_1 = require("./utils");
const unist_util_select_1 = require("unist-util-select");
const types_1 = require("./types");
class Jats {
    constructor(data) {
        this.raw = (0, xml_js_1.xml2js)(data, { compact: false });
        const { declaration, elements } = this.raw;
        this.declaration = declaration === null || declaration === void 0 ? void 0 : declaration.attributes;
        if (!((elements === null || elements === void 0 ? void 0 : elements.length) === 2 && elements[0].type === 'doctype' && elements[1].name === 'article')) {
            throw new Error('article is not the only element of the JATS');
        }
        this.doctype = elements[0].doctype;
        this.tree = (0, utils_1.convertToUnist)(elements[1]);
    }
    get front() {
        return (0, unist_util_select_1.select)(types_1.Tags.front, this.tree);
    }
    get premissions() {
        return (0, unist_util_select_1.select)(types_1.Tags.permissions, this.front);
    }
    get doi() {
        return (0, utils_1.findDoi)(this.front);
    }
    get publicationDates() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.pubDate, this.front);
    }
    get publicationDate() {
        return this.publicationDates.find((d) => !!(0, unist_util_select_1.select)(types_1.Tags.day, d));
    }
    get license() {
        return (0, unist_util_select_1.select)(types_1.Tags.license, this.premissions);
    }
    get keywordGroup() {
        return (0, unist_util_select_1.select)(types_1.Tags.kwdGroup, this.front);
    }
    /** The first keywords */
    get keywords() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.kwd, this.keywordGroup);
    }
    get keywordGroups() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.kwdGroup, this.front);
    }
    get titleGroup() {
        return (0, unist_util_select_1.select)(types_1.Tags.titleGroup, this.front);
    }
    get articleTitle() {
        return (0, unist_util_select_1.select)(types_1.Tags.articleTitle, this.titleGroup);
    }
    get articleSubtitle() {
        return (0, unist_util_select_1.select)(types_1.Tags.subtitle, this.titleGroup);
    }
    get abstract() {
        return (0, unist_util_select_1.select)(types_1.Tags.abstract, this.front);
    }
    get abstracts() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.abstract, this.front);
    }
    get contribGroup() {
        return (0, unist_util_select_1.select)(types_1.Tags.contribGroup, this.front);
    }
    get contribGroups() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.contribGroup, this.front);
    }
    get articleAuthors() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.contrib, this.contribGroup);
    }
    get body() {
        return (0, unist_util_select_1.select)(types_1.Tags.body, this.tree);
    }
    get back() {
        return (0, unist_util_select_1.select)(types_1.Tags.back, this.tree);
    }
    get subArticles() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.subArticle, this.tree);
    }
    get refList() {
        return (0, unist_util_select_1.select)(types_1.Tags.refList, this.back);
    }
    get references() {
        return (0, unist_util_select_1.selectAll)(types_1.Tags.ref, this.refList);
    }
}
exports.Jats = Jats;
