"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveJatsUrlFromDoi = exports.DEFAULT_RESOLVERS = exports.joss = exports.plos = exports.elife = void 0;
const doi_utils_1 = __importDefault(require("doi-utils"));
const node_fetch_1 = __importDefault(require("node-fetch"));
exports.elife = {
    test(url) {
        return new URL(url).hostname === 'elifesciences.org';
    },
    jatsUrl(url) {
        return `${url}.xml`;
    },
};
exports.plos = {
    test(url) {
        return new URL(url).hostname === 'journals.plos.org';
    },
    jatsUrl(url) {
        return url.replace('/article?', '/article/file?') + '&type=manuscript';
    },
};
exports.joss = {
    test(url) {
        return new URL(url).hostname === 'joss.theoj.org' && doi_utils_1.default.validate(url);
    },
    jatsUrl(url) {
        // Probably a better way to do this, the joss papers on on github!
        const doiString = doi_utils_1.default.normalize(url);
        const [org, jossId] = doiString.split('/');
        const id = jossId.split('.')[1];
        return `https://raw.githubusercontent.com/openjournals/joss-papers/master/joss.${id}/${org}.${jossId}.jats`;
    },
};
exports.DEFAULT_RESOLVERS = [exports.elife, exports.plos, exports.joss];
function resolveJatsUrlFromDoi(session, doiString, resolvers = exports.DEFAULT_RESOLVERS) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!doi_utils_1.default.validate(doiString))
            throw new Error(`The doi ${doiString} is not valid`);
        const doiUrl = doi_utils_1.default.buildUrl(doiString);
        session.log.debug(`Resolving DOI ${doiUrl}`);
        const resp = yield (0, node_fetch_1.default)(doiUrl);
        const articleUrl = resp.url;
        session.log.debug(`Found resolved URL for DOI at ${articleUrl}`);
        const resolver = resolvers.find((r) => r.test(articleUrl));
        if (!resolver)
            throw new Error(`Could not resolve JATS for ${articleUrl}, no resolver matched`);
        const jatsUrl = resolver.jatsUrl(articleUrl);
        return jatsUrl;
    });
}
exports.resolveJatsUrlFromDoi = resolveJatsUrlFromDoi;
