"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findDoi = exports.formatDate = exports.toDate = exports.convertToUnist = void 0;
const myst_common_1 = require("myst-common");
const doi_utils_1 = __importDefault(require("doi-utils"));
const unist_util_select_1 = require("unist-util-select");
const types_1 = require("./types");
function convertToUnist(node) {
    switch (node.type) {
        case 'element': {
            const { name, attributes, elements } = node;
            const children = elements === null || elements === void 0 ? void 0 : elements.map(convertToUnist);
            const next = Object.assign({ type: name !== null && name !== void 0 ? name : 'unknown' }, attributes);
            if (children)
                next.children = children;
            return next;
        }
        case 'text': {
            const { attributes, text } = node;
            return Object.assign(Object.assign({ type: 'text' }, attributes), { value: String(text) });
        }
        case 'cdata': {
            const { attributes, cdata } = node;
            return Object.assign(Object.assign({ type: 'cdata' }, attributes), { cdata });
        }
        case 'comment': {
            const { comment } = node;
            return { type: 'comment', value: String(comment) };
        }
        default:
            console.log(node);
            throw new Error(`found ${node.type} ${node.name}`);
    }
}
exports.convertToUnist = convertToUnist;
const MonthLookup = {
    jan: 0,
    january: 0,
    feb: 1,
    february: 1,
    mar: 2,
    march: 2,
    apr: 3,
    april: 3,
    may: 4,
    jun: 5,
    june: 5,
    jul: 6,
    july: 6,
    aug: 7,
    august: 7,
    sep: 8,
    sept: 8,
    september: 8,
    oct: 9,
    october: 9,
    nov: 10,
    november: 10,
    dec: 11,
    december: 11,
};
function toDate(date) {
    if (!date)
        return;
    const isoDate = date['iso-8601-date'];
    if (isoDate)
        return new Date(isoDate);
    const year = Number((0, myst_common_1.toText)((0, unist_util_select_1.select)('year', date)));
    if (!year || Number.isNaN(year))
        return;
    const monthText = (0, myst_common_1.toText)((0, unist_util_select_1.select)('month', date));
    const monthTextNumber = Number(monthText);
    const month = Number.isNaN(monthTextNumber) ? MonthLookup[monthText] : monthTextNumber - 1;
    if (month == null)
        return new Date(Date.UTC(year, 0));
    const day = Number((0, myst_common_1.toText)((0, unist_util_select_1.select)('day', date)));
    if (!day || Number.isNaN(day))
        return new Date(Date.UTC(year, month));
    return new Date(Date.UTC(year, month, day));
}
exports.toDate = toDate;
function formatDate(date) {
    if (!date)
        return;
    return new Intl.DateTimeFormat('en-US', { dateStyle: 'long', timeZone: 'UTC' }).format(date);
}
exports.formatDate = formatDate;
function findDoi(node) {
    const id = (0, unist_util_select_1.select)('[pub-id-type=doi]', node);
    if (id && (0, myst_common_1.toText)(id))
        return (0, myst_common_1.toText)(id);
    const doiTag = (0, unist_util_select_1.selectAll)(`${types_1.Tags.articleId},${types_1.Tags.pubId}`, node).find((t) => doi_utils_1.default.validate((0, myst_common_1.toText)(t)));
    return (0, myst_common_1.toText)(doiTag) || null;
}
exports.findDoi = findDoi;
